@@ -28,7 +28,7 @@ class DynamicForkTask(TaskInterface):
 
     def to_workflow_task(self) -> List[WorkflowTaskAdapter]:
         wf_task = super().to_workflow_task()
-        wf_task.dynamic_fork_join_tasks_param = self.tasks_param
+        wf_task.dynamic_fork_tasks_param = self.tasks_param
         wf_task.dynamic_fork_tasks_input_param_name = self.tasks_input_param_name
 
         tasks = [wf_task]
