@@ -4,7 +4,9 @@ import json
 
 import logging
 import os
+import re
 import time
+import warnings
 from typing import Optional, Dict, Union
 
 from conductor.shared.configuration.settings.authentication_settings import (
@@ -13,6 +15,58 @@ from conductor.shared.configuration.settings.authentication_settings import (
 
 
 class Configuration:
+    """
+    Configuration class for Orkes Conductor Sync Client with environment variable support.
+
+    This class provides configuration for the synchronous Conductor client with support for:
+    - Environment variable configuration for standard Conductor settings
+    - Worker properties configuration (pollInterval, domain, etc.)
+    - Authentication retry policy with exponential backoff
+
+    Supported Environment Variables:
+    --------------------------------
+    CONDUCTOR_SERVER_URL: Server URL (e.g., http://localhost:8080/api)
+    CONDUCTOR_UI_SERVER_URL: UI Server URL (e.g., http://localhost:5001)
+    CONDUCTOR_AUTH_KEY: Authentication key ID
+    CONDUCTOR_AUTH_SECRET: Authentication key secret
+
+    Worker Properties (via environment variables):
+    ----------------------------------------------
+    CONDUCTOR_WORKER_DOMAIN: Default worker domain (default: 'default_domain')
+    CONDUCTOR_WORKER_POLL_INTERVAL: Polling interval in milliseconds (default: 100)
+    CONDUCTOR_WORKER_POLL_INTERVAL_SECONDS: Polling interval in seconds (default: 0)
+
+    Authentication Retry Policy (401 Handling):
+    -------------------------------------------
+    CONDUCTOR_AUTH_401_MAX_ATTEMPTS: Maximum retry attempts per endpoint (default: 6)
+    CONDUCTOR_AUTH_401_BASE_DELAY_MS: Base delay in milliseconds (default: 1000.0)
+    CONDUCTOR_AUTH_401_MAX_DELAY_MS: Maximum delay cap in milliseconds (default: 60000.0)
+    CONDUCTOR_AUTH_401_JITTER_PERCENT: Random jitter percentage 0.0-1.0 (default: 0.2)
+    CONDUCTOR_AUTH_401_STOP_BEHAVIOR: Behavior after max attempts: 'stop_worker' or 'continue' (default: 'stop_worker')
+
+    Example:
+    --------
+    ```python
+    # Using environment variables
+    import os
+    os.environ['CONDUCTOR_SERVER_URL'] = 'http://localhost:8080/api'
+    os.environ['CONDUCTOR_AUTH_KEY'] = 'your_key'
+    os.environ['CONDUCTOR_AUTH_SECRET'] = 'your_secret'
+
+    config = Configuration()
+
+    # Or with explicit parameters
+    from conductor.client.configuration.settings.authentication_settings import AuthenticationSettings
+
+    auth_settings = AuthenticationSettings(key_id='your_key', key_secret='your_secret')
+    config = Configuration(
+        server_api_url='http://localhost:8080/api',
+        authentication_settings=auth_settings,
+        auth_401_max_attempts=5,
+        auth_401_base_delay_ms=1000.0
+    )
+    ```
+    """
     AUTH_TOKEN = None
 
     def __init__(
@@ -32,6 +86,12 @@ class Configuration:
         cert_file: Optional[str] = None,
         key_file: Optional[str] = None,
         verify_ssl: Optional[bool] = None,
+        # 401-specific configuration
+        auth_401_max_attempts: Optional[int] = None,
+        auth_401_base_delay_ms: Optional[float] = None,
+        auth_401_max_delay_ms: Optional[float] = None,
+        auth_401_jitter_percent: Optional[float] = None,
+        auth_401_stop_behavior: Optional[str] = None,
     ):
         """
         Initialize Conductor client configuration.
@@ -55,7 +115,13 @@ class Configuration:
         if server_api_url is not None:
             self.host = server_api_url
         elif base_url is not None:
-            self.host = base_url + "/api"
+            if re.search(r'/api(/|$)', base_url):
+                warnings.warn(
+                    "'base_url' been passed with '/api' path. Consider using 'server_api_url' instead"
+                )
+            else:
+                base_url += "/api"
+            self.host = base_url
         else:
             self.host = os.getenv("CONDUCTOR_SERVER_URL")
 
@@ -73,9 +139,7 @@ class Configuration:
             key = os.getenv("CONDUCTOR_AUTH_KEY")
             secret = os.getenv("CONDUCTOR_AUTH_SECRET")
             if key is not None and secret is not None:
-                self.authentication_settings = AuthenticationSettings(
-                    key_id=key, key_secret=secret
-                )
+                self.authentication_settings = AuthenticationSettings(key_id=key, key_secret=secret)
             else:
                 self.authentication_settings = None
 
@@ -129,11 +193,28 @@ class Configuration:
         self.polling_interval = polling_interval or self._get_env_float(
             "CONDUCTOR_WORKER_POLL_INTERVAL", 100
         )
-        self.domain = domain or os.getenv("CONDUCTOR_WORKER_DOMAIN", "default_domain")
+        self.domain = domain or os.getenv("CONDUCTOR_WORKER_DOMAIN", None)
         self.polling_interval_seconds = polling_interval_seconds or self._get_env_float(
             "CONDUCTOR_WORKER_POLL_INTERVAL_SECONDS", 0
         )
 
+        # 401-specific configuration
+        self.auth_401_max_attempts = auth_401_max_attempts or self._get_env_int(
+            "CONDUCTOR_AUTH_401_MAX_ATTEMPTS", 6
+        )
+        self.auth_401_base_delay_ms = auth_401_base_delay_ms or self._get_env_float(
+            "CONDUCTOR_AUTH_401_BASE_DELAY_MS", 1000.0
+        )
+        self.auth_401_max_delay_ms = auth_401_max_delay_ms or self._get_env_float(
+            "CONDUCTOR_AUTH_401_MAX_DELAY_MS", 60000.0
+        )
+        self.auth_401_jitter_percent = auth_401_jitter_percent or self._get_env_float(
+            "CONDUCTOR_AUTH_401_JITTER_PERCENT", 0.2
+        )
+        self.auth_401_stop_behavior = auth_401_stop_behavior or os.getenv(
+            "CONDUCTOR_AUTH_401_STOP_BEHAVIOR", "stop_worker"
+        )
+
     @property
     def debug(self):
         """Debug status
@@ -228,6 +309,16 @@ class Configuration:
             pass
         return default
 
+    def _get_env_int(self, env_var: str, default: int) -> int:
+        """Get int value from environment variable with default fallback."""
+        try:
+            value = os.getenv(env_var)
+            if value is not None:
+                return int(value)
+        except (ValueError, TypeError):
+            pass
+        return default
+
     def _get_env_bool(self, env_var: str, default: bool) -> bool:
         """Get boolean value from environment variable with default fallback."""
         value = os.getenv(env_var)
