@@ -1,12 +1,12 @@
-from abc import ABC
-from typing import Any, Dict
+from abc import ABC, abstractmethod
+from typing import Any, ClassVar, Dict
 
 from conductor.client.event.queue.queue_worker_configuration import QueueWorkerConfiguration
 
 
 class QueueConfiguration(ABC):
-    WORKER_CONSUMER_KEY = "consumer"
-    WORKER_PRODUCER_KEY = "producer"
+    WORKER_CONSUMER_KEY: ClassVar[str] = "consumer"
+    WORKER_PRODUCER_KEY: ClassVar[str] = "producer"
 
     def __init__(self, queue_name: str, queue_type: str):
         self.queue_name = queue_name
@@ -19,5 +19,6 @@ class QueueConfiguration(ABC):
     def add_producer(self, worker_configuration: QueueWorkerConfiguration) -> None:
         self.worker_configuration[self.WORKER_PRODUCER_KEY] = worker_configuration
 
+    @abstractmethod
     def get_worker_configuration(self) -> Dict[str, Any]:
         raise NotImplementedError
