@@ -1,8 +1,12 @@
-from typing import Optional, List
+from __future__ import annotations
+from typing import Optional, List, Dict
+import uuid
 
 from conductor.client.configuration.configuration import Configuration
-from conductor.client.http.models import SkipTaskRequest, WorkflowStatus, \
-    ScrollableSearchResultWorkflowSummary
+from conductor.client.http.models.skip_task_request import SkipTaskRequest
+from conductor.client.http.models.workflow_status import WorkflowStatus
+from conductor.client.http.models.scrollable_search_result_workflow_summary import ScrollableSearchResultWorkflowSummary
+from conductor.client.http.models.signal_response import SignalResponse
 from conductor.client.http.models.correlation_ids_search_request import CorrelationIdsSearchRequest
 from conductor.client.http.models.rerun_workflow_request import RerunWorkflowRequest
 from conductor.client.http.models.start_workflow_request import StartWorkflowRequest
@@ -24,7 +28,7 @@ class OrkesWorkflowClient(OrkesBaseClient, WorkflowClient):
     def start_workflow_by_name(
             self,
             name: str,
-            input: dict[str, object],
+            input: Dict[str, object],
             version: Optional[int] = None,
             correlationId: Optional[str] = None,
             priority: Optional[int] = None,
@@ -45,7 +49,7 @@ class OrkesWorkflowClient(OrkesBaseClient, WorkflowClient):
     def execute_workflow(
             self,
             start_workflow_request: StartWorkflowRequest,
-            request_id: str = None,
+            request_id: Optional[str] = None,
             wait_until_task_ref: Optional[str] = None,
             wait_for_seconds: int = 30
     ) -> WorkflowRun:
@@ -59,6 +63,40 @@ class OrkesWorkflowClient(OrkesBaseClient, WorkflowClient):
             wait_for_seconds=wait_for_seconds,
         )
 
+    def execute_workflow_with_return_strategy(
+            self,
+            start_workflow_request: StartWorkflowRequest,
+            request_id: Optional[str] = None,
+            wait_until_task_ref: Optional[str] = None,
+            wait_for_seconds: int = 30,
+            consistency: Optional[str] = None,
+            return_strategy: Optional[str] = None
+    ) -> SignalResponse:
+        """Execute a workflow synchronously with optional reactive features
+        Args:
+            start_workflow_request: StartWorkflowRequest containing workflow details
+            request_id: Optional request ID for tracking
+            wait_until_task_ref: Wait until this task reference is reached
+            wait_for_seconds: How long to wait for completion (default 30)
+            consistency: Workflow consistency level - 'DURABLE' or 'SYNCHRONOUS' or 'REGION_DURABLE'
+            return_strategy: Return strategy - 'TARGET_WORKFLOW' or 'BLOCKING_WORKFLOW' or 'BLOCKING_TASK' or 'BLOCKING_TASK_INPUT'
+        Returns:
+            WorkflowRun: The workflow execution result
+        """
+        if consistency is None:
+            consistency = "DURABLE"
+        if return_strategy is None:
+            return_strategy = "TARGET_WORKFLOW"
+
+        return self.workflowResourceApi.execute_workflow_with_return_strategy(body=start_workflow_request,
+                                                                              name=start_workflow_request.name,
+                                                                              version=start_workflow_request.version,
+                                                                              request_id=request_id,
+                                                                              wait_until_task_ref=wait_until_task_ref,
+                                                                              wait_for_seconds=wait_for_seconds,
+                                                                              consistency=consistency,
+                                                                              return_strategy=return_strategy)
+
     def pause_workflow(self, workflow_id: str):
         self.workflowResourceApi.pause_workflow(workflow_id)
 
@@ -68,7 +106,7 @@ class OrkesWorkflowClient(OrkesBaseClient, WorkflowClient):
     def restart_workflow(self, workflow_id: str, use_latest_def: Optional[bool] = False):
         kwargs = {}
         if use_latest_def:
-            kwargs['use_latest_definitions'] = use_latest_def
+            kwargs["use_latest_definitions"] = use_latest_def
         self.workflowResourceApi.restart(workflow_id, **kwargs)
 
     def rerun_workflow(self, workflow_id: str, rerun_workflow_request: RerunWorkflowRequest) -> str:
@@ -78,35 +116,35 @@ class OrkesWorkflowClient(OrkesBaseClient, WorkflowClient):
     def retry_workflow(self, workflow_id: str, resume_subworkflow_tasks: Optional[bool] = False):
         kwargs = {}
         if resume_subworkflow_tasks:
-            kwargs['resume_subworkflow_tasks'] = resume_subworkflow_tasks
+            kwargs["resume_subworkflow_tasks"] = resume_subworkflow_tasks
         self.workflowResourceApi.retry(workflow_id, **kwargs)
 
     def terminate_workflow(self, workflow_id: str, reason: Optional[str] = None,
                            trigger_failure_workflow: bool = False):
         kwargs = {}
         if reason:
-            kwargs['reason'] = reason
+            kwargs["reason"] = reason
         if trigger_failure_workflow:
-            kwargs['trigger_failure_workflow'] = trigger_failure_workflow
-        self.workflowResourceApi.terminate(workflow_id, **kwargs)
+            kwargs["trigger_failure_workflow"] = trigger_failure_workflow
+        self.workflowResourceApi.terminate1(workflow_id, **kwargs)
 
     def get_workflow(self, workflow_id: str, include_tasks: Optional[bool] = True) -> Workflow:
         kwargs = {}
         if include_tasks:
-            kwargs['include_tasks'] = include_tasks
+            kwargs["include_tasks"] = include_tasks
         return self.workflowResourceApi.get_execution_status(workflow_id, **kwargs)
 
-    def get_workflow_status(self, workflow_id: str, include_output: bool = None,
-                            include_variables: bool = None) -> WorkflowStatus:
+    def get_workflow_status(self, workflow_id: str, include_output: Optional[bool] = None,
+                            include_variables: Optional[bool] = None) -> WorkflowStatus:
         kwargs = {}
         if include_output is not None:
-            kwargs['include_output'] = include_output
+            kwargs["include_output"] = include_output
         if include_variables is not None:
-            kwargs['include_variables'] = include_variables
+            kwargs["include_variables"] = include_variables
         return self.workflowResourceApi.get_workflow_status_summary(workflow_id, **kwargs)
 
     def delete_workflow(self, workflow_id: str, archive_workflow: Optional[bool] = True):
-        self.workflowResourceApi.delete(workflow_id, archive_workflow=archive_workflow)
+        self.workflowResourceApi.delete1(workflow_id, archive_workflow=archive_workflow)
 
     def skip_task_from_workflow(self, workflow_id: str, task_reference_name: str, request: SkipTaskRequest):
         self.workflowResourceApi.skip_task_from_workflow(workflow_id, task_reference_name, request)
@@ -114,14 +152,14 @@ class OrkesWorkflowClient(OrkesBaseClient, WorkflowClient):
     def test_workflow(self, test_request: WorkflowTestRequest) -> Workflow:
         return self.workflowResourceApi.test_workflow(test_request)
 
-    def search(self, start: int = 0, size: int = 100, free_text: str = '*', query: str = None,
-               query_id: str = None) -> ScrollableSearchResultWorkflowSummary:
+    def search(self, start: int = 0, size: int = 100, free_text: str = "*", query: Optional[str] = None,
+               query_id: Optional[str] = None, skip_cache: bool = False) -> ScrollableSearchResultWorkflowSummary:
         args = {
-            'start': start,
-            'size': size,
-            'free_text': free_text,
-            'query': query,
-            'query_id': query_id
+            "start": start,
+            "size": size,
+            "free_text": free_text,
+            "query": query,
+            "skip_cache": skip_cache
 
         }
         return self.workflowResourceApi.search(**args)
@@ -130,19 +168,19 @@ class OrkesWorkflowClient(OrkesBaseClient, WorkflowClient):
             self,
             batch_request: CorrelationIdsSearchRequest,
             include_completed: bool = False,
-            include_tasks: bool = False) -> dict[str, List[Workflow]]:
+            include_tasks: bool = False) -> Dict[str, List[Workflow]]:
 
         """Given the list of correlation ids and list of workflow names, find and return workflows
         Returns a map with key as correlationId and value as a list of Workflows
         When IncludeClosed is set to true, the return value also includes workflows that are completed otherwise only running workflows are returned"""
         kwargs = {}
 
-        kwargs['body'] = batch_request
+        kwargs["body"] = batch_request
         if include_tasks:
-            kwargs['include_tasks'] = include_tasks
+            kwargs["include_tasks"] = include_tasks
         if include_completed:
-            kwargs['include_closed'] = include_completed
-        return self.workflowResourceApi.get_workflows_by_correlation_id_in_batch(**kwargs)
+            kwargs["include_closed"] = include_completed
+        return self.workflowResourceApi.get_workflows1(**kwargs)
 
     def get_by_correlation_ids(
             self,
@@ -150,13 +188,13 @@ class OrkesWorkflowClient(OrkesBaseClient, WorkflowClient):
             correlation_ids: List[str],
             include_completed: bool = False,
             include_tasks: bool = False
-    ) -> dict[str, List[Workflow]]:
+    ) -> Dict[str, List[Workflow]]:
         """Lists workflows for the given correlation id list"""
         kwargs = {}
         if include_tasks:
-            kwargs['include_tasks'] = include_tasks
+            kwargs["include_tasks"] = include_tasks
         if include_completed:
-            kwargs['include_closed'] = include_completed
+            kwargs["include_closed"] = include_completed
 
         return self.workflowResourceApi.get_workflows(
             body=correlation_ids,
@@ -165,17 +203,19 @@ class OrkesWorkflowClient(OrkesBaseClient, WorkflowClient):
         )
 
     def remove_workflow(self, workflow_id: str):
-        self.workflowResourceApi.delete(workflow_id)
+        self.workflowResourceApi.delete1(workflow_id)
 
-    def update_variables(self, workflow_id: str, variables: dict[str, object] = {}) -> None:
+    def update_variables(self, workflow_id: str, variables: Optional[Dict[str, object]] = None) -> None:
+        variables = variables or {}
         self.workflowResourceApi.update_workflow_state(variables, workflow_id)
 
-    def update_state(self, workflow_id: str, update_requesst: WorkflowStateUpdate,
-                     wait_until_task_ref_names: List[str] = None, wait_for_seconds: int = None) -> WorkflowRun:
+    def update_state(self, workflow_id: str, update_request: WorkflowStateUpdate,
+                     wait_until_task_ref_names: Optional[List[str]] = None, wait_for_seconds: Optional[int] = None) -> WorkflowRun:
         kwargs = {}
+        request_id=str(uuid.uuid4())
         if wait_until_task_ref_names is not None:
-            kwargs['wait_until_task_ref'] = ','.join(wait_until_task_ref_names)
+            kwargs["wait_until_task_ref"] = ",".join(wait_until_task_ref_names)
         if wait_for_seconds is not None:
-            kwargs['wait_for_seconds'] = wait_for_seconds
+            kwargs["wait_for_seconds"] = wait_for_seconds
 
-        return self.workflowResourceApi.update_workflow_and_task_state(update_requesst=update_requesst, workflow_id=workflow_id, **kwargs)
\ No newline at end of file
+        return self.workflowResourceApi.update_workflow_and_task_state(body=update_request, workflow_id=workflow_id, request_id=request_id, **kwargs)
