@@ -1,4 +1,5 @@
-from typing import List
+from __future__ import annotations
+from typing import List, Optional
 
 from typing_extensions import Self
 
@@ -8,9 +9,9 @@ from conductor.client.workflow.task.task_type import TaskType
 
 class LlmQueryEmbeddings(TaskInterface):
     def __init__(self, task_ref_name: str, vector_db: str, index: str,
-                 embeddings: List[int], task_name: str = None, namespace: str = None) -> Self:
+                 embeddings: List[int], task_name: Optional[str] = None, namespace: Optional[str] = None) -> Self:
         if task_name is None:
-            task_name = 'llm_get_embeddings'
+            task_name = "llm_get_embeddings"
 
         super().__init__(
             task_name=task_name,
